import { 
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.L1_AFWell;
  const yValue = d => d.Age;
  const margin = { top: 20, right: 20, bottom: 20, left: 50};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left}, ${margin.top})`);

  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
    .attr('transform', `translate(0, ${innerHeight})`);
        
        
  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth())
  };

csv('data.csv').then(data => {
    data.forEach(d => {
      d.Year = parseFloat(d.Year);
      d.Age = parseFloat(d.Age);
      d.Check = parseFloat(d.Check);
      d["L1_AFWell"] = parseFloat(d["L1_AFWell"]);
      d["L1_S"] = parseFloat(d["L1_S"]);
      d["L1_B"] = parseFloat(d["L1_B"]);
      d["L1_M"] = parseFloat(d["L1_M"]);
      d["L1_ICH"] = parseFloat(d["L1_ICH"]);
      d["L1_S_B"] = parseFloat(d["L1_S_B"]);
      d["L1_S_M"] = parseFloat(d["L1_S_M"]);
      d["L1_S_ICH"] = parseFloat(d["L1_S_ICH"]);
      d["L1_B_M"] = parseFloat(d["L1_B_M"]);
      d["L1_B_ICH"] = parseFloat(d["L1_B_ICH"]);
      d["L1_MI_ICH"] = parseFloat(d["L1_MI_ICH"]);
      d["L1_S_B_M"] = parseFloat(d["L1_S_B_M"]);
      d["L1_S_B_ICH"] = parseFloat(d["L1_S_B_ICH"]);
      d["L1_S_MI_ICH"] = parseFloat(d["L1_S_MI_ICH"]);
      d["L1_B_M_ICH"] = parseFloat(d["L1_B_M_ICH"]);
      d["L1_S_B_M_ICH"] = parseFloat(d["L1_S_B_M_ICH"]);
      d["L1_Dead"] = parseFloat(d["L1_Dead"]);
      d["L2_AFWell"] = parseFloat(d["L2_AFWell"]);
      d["L2_S"] = parseFloat(d["L2_S"]);
      d["L2_B"] = parseFloat(d["L2_B"]);
      d["L2_M"] = parseFloat(d["L2_M"]);
      d["L2_ICH"] = parseFloat(d["L2_ICH"]);
      d["L2_S_B"] = parseFloat(d["L2_S_B"]);
      d["L2_S_M"] = parseFloat(d["L2_S_M"]);
      d["L2_S_ICH"] = parseFloat(d["L2_S_ICH"]);
      d["L2_B_M"] = parseFloat(d["L2_B_M"]);
      d["L2_B_ICH"] = parseFloat(d["L2_B_ICH"]);
      d["L2_MI_ICH"] = parseFloat(d["L2_MI_ICH"]);
      d["L2_S_B_M"] = parseFloat(d["L2_S_B_M"]);
      d["L2_S_B_ICH"] = parseFloat(d["L2_S_B_ICH"]);
      d["L2_S_MI_ICH"] = parseFloat(d["L2_S_MI_ICH"]);
      d["L2_B_M_ICH"] = parseFloat(d["L2_B_M_ICH"]);
      d["L2_S_B_M_ICH"] = parseFloat(d["L2_S_B_M_ICH"]);
      d["L2_Dead"] = parseFloat(d["L2_Dead"]);
  });
  render(data);
  console.log(data);
});










